import { AfterViewInit, ElementRef, TemplateRef, AfterContentInit } from '@angular/core';
import { TextAreaDirective } from './text-area.directive';
import * as i0 from "@angular/core";
/**
 * [See demo](../../?path=/story/input--label)
 *
 * ```html
 * <ofe-label labelState="success">
 *     <label label>Field with success</label>
 *     <input type="text" class="input-field">
 * </ofe-label>
 *
 * <ofe-label labelState="warning">
 *     <label label>Field with warning</label>
 *     <input type="text" class="input-field">
 * </ofe-label>
 *
 * <ofe-label labelState="error">
 *     <label label>Field with error</label>
 *     <input type="text" class="input-field">
 * </ofe-label>
 * ```
 *
 * <example-url>../../iframe.html?id=input--label</example-url>
 */
export declare class LabelComponent implements AfterContentInit, AfterViewInit {
    /**
     * Used to build the id of the input item associated with the `Label`.
     */
    static labelCounter: number;
    /**
     * The class of the wrapper
     */
    wrapperClass: string;
    /**
     * The id of the input item associated with the `Label`. This value is also used to associate the `Label` with
     * its input counterpart through the 'for' attribute.
     */
    labelInputID: string;
    /**
     * State of the `Label` will determine the styles applied.
     */
    labelState: 'success' | 'warning' | 'error' | '';
    /**
     * Set to `true` for a loading label.
     */
    skeleton: boolean;
    /**
     * Optional helper text that appears under the label.
     */
    helperText: string | TemplateRef<any>;
    /**
     * Sets the invalid text.
     */
    invalidText: string | TemplateRef<any>;
    /**
     * Set to `true` for an invalid label component.
     */
    invalid: boolean;
    /**
     * Set to `true` to show a warning (contents set by warningText)
     */
    warn: boolean;
    /**
     * Sets the warning text
     */
    warnText: string | TemplateRef<any>;
    /**
     * Set the arialabel for label
     */
    ariaLabel: string;
    wrapper: ElementRef<HTMLDivElement>;
    textArea: TextAreaDirective;
    labelClass: boolean;
    /**
     * Creates an instance of LabelComponent.
     */
    constructor();
    /**
     * Update wrapper class if a textarea is hosted.
     */
    ngAfterContentInit(): void;
    /**
     * Sets the id on the input item associated with the `Label`.
     */
    ngAfterViewInit(): void;
    isTemplate(value: any): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<LabelComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LabelComponent, "ofe-label", never, { "labelInputID": { "alias": "labelInputID"; "required": false; }; "labelState": { "alias": "labelState"; "required": false; }; "skeleton": { "alias": "skeleton"; "required": false; }; "helperText": { "alias": "helperText"; "required": false; }; "invalidText": { "alias": "invalidText"; "required": false; }; "invalid": { "alias": "invalid"; "required": false; }; "warn": { "alias": "warn"; "required": false; }; "warnText": { "alias": "warnText"; "required": false; }; "ariaLabel": { "alias": "ariaLabel"; "required": false; }; }, {}, ["textArea"], ["*", "input,textarea,div"], false, never>;
}
