/**
 * date-time.class
 */
import { EventEmitter } from '@angular/core';
import { DateTimeAdapter } from './adapter/date-time-adapter.class';
import { OwlDateTimeFormats } from './adapter/date-time-format.class';
import * as i0 from "@angular/core";
export type PickerType = 'both' | 'calendar' | 'timer';
export type PickerMode = 'popup' | 'dialog' | 'inline';
export type SelectMode = 'single' | 'range' | 'rangeFrom' | 'rangeTo';
export declare abstract class OwlDateTime<T> {
    protected dateTimeAdapter: DateTimeAdapter<T>;
    protected dateTimeFormats: OwlDateTimeFormats;
    get showSecondsTimer(): boolean;
    set showSecondsTimer(val: boolean);
    get hour12Timer(): boolean;
    set hour12Timer(val: boolean);
    get stepHour(): number;
    set stepHour(val: number);
    get stepMinute(): number;
    set stepMinute(val: number);
    get stepSecond(): number;
    set stepSecond(val: number);
    get firstDayOfWeek(): number;
    set firstDayOfWeek(value: number);
    get hideOtherMonths(): boolean;
    set hideOtherMonths(val: boolean);
    get id(): string;
    abstract get selected(): T | null;
    abstract get selecteds(): T[] | null;
    abstract get dateTimeFilter(): (date: T | null) => boolean;
    abstract get maxDateTime(): T | null;
    abstract get minDateTime(): T | null;
    abstract get selectMode(): SelectMode;
    abstract get startAt(): T | null;
    abstract get opened(): boolean;
    abstract get pickerMode(): PickerMode;
    abstract get pickerType(): PickerType;
    abstract get isInSingleMode(): boolean;
    abstract get isInRangeMode(): boolean;
    get formatString(): string;
    get disabled(): boolean;
    constructor(dateTimeAdapter: DateTimeAdapter<T>, dateTimeFormats: OwlDateTimeFormats);
    /**
     * Whether to show the second's timer
     */
    private _showSecondsTimer;
    /**
     * Whether the timer is in hour12 format
     */
    private _hour12Timer;
    /**
     * The view that the calendar should start in.
     */
    startView: 'month' | 'year' | 'multi-years';
    /**
     * Hours to change per step
     */
    private _stepHour;
    /**
     * Minutes to change per step
     */
    private _stepMinute;
    /**
     * Seconds to change per step
     */
    private _stepSecond;
    /**
     * Set the first day of week
     */
    private _firstDayOfWeek;
    /**
     * Whether to hide dates in other months at the start or end of the current month.
     */
    private _hideOtherMonths;
    private _id;
    abstract yearSelected: EventEmitter<T>;
    abstract monthSelected: EventEmitter<T>;
    abstract select(date: T | T[]): void;
    abstract selectYear(normalizedYear: T): void;
    abstract selectMonth(normalizedMonth: T): void;
    /**
     * Date Time Checker to check if the give dateTime is selectable
     */
    dateTimeChecker: (dateTime: T) => boolean;
    protected getValidDate(obj: any): T | null;
    static ɵfac: i0.ɵɵFactoryDeclaration<OwlDateTime<any>, [{ optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<OwlDateTime<any>>;
}
