import { EventEmitter, TemplateRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import * as i0 from "@angular/core";
/**
 * Used to emit changes performed on number input components.
 */
export declare class NumberChangeEvent {
    /**
     * Contains the `NumberInputComponent` that has been changed.
     */
    source: NumberInputComponent;
    /**
     * The value of the `NumberInputComponent` field encompassed in the `NumberChange` class.
     */
    value: number;
}
export declare class NumberInputComponent implements ControlValueAccessor {
    /**
     * Variable used for creating unique ids for number input components.
     */
    static numberCount: number;
    /**
     * `light` or `dark` number input theme.
     */
    theme: 'light' | 'dark';
    /**
     * Set to `true` for a disabled number input.
     */
    disabled: boolean;
    /**
     * Set to `true` for a loading number component.
     */
    skeleton: boolean;
    /**
     * Set to `true` for an invalid number component.
     */
    invalid: boolean;
    /**
     * The unique id for the number component.
     */
    id: string;
    /**
     * Sets the placeholder attribute on the `input` element.
     */
    placeholder: string;
    /**
     * Number input field render size
     */
    size: 'sm' | 'md' | 'lg';
    /**
     * Reflects the required attribute of the `input` element.
     */
    required: boolean;
    /**
     * Sets the value attribute on the `input` element.
     */
    set value(v: any);
    get value(): any;
    /**
     * Sets the min attribute on the `input` element.
     */
    min: any;
    /**
     * Sets the max attribute on the `input` element.
     */
    max: any;
    /**
     * Sets the max length attribute on the `input` element.
     */
    maxlength: any;
    /**
     * Sets the min length attribute on the `input` element.
     */
    minlength: any;
    /**
     * Sets the text inside the `label` tag.
     */
    label: string | TemplateRef<any>;
    /**
     * Sets the optional helper text.
     */
    helperText: string | TemplateRef<any>;
    /**
     * Sets the invalid text.
     */
    invalidText: string | TemplateRef<any>;
    /**
     * Sets the amount the number controls increment and decrement by.
     */
    step: number;
    /**
     * If `step` is a decimal, we may want precision to be set to go around floating point precision.
     */
    precision: number;
    /**
     * Set to `true` to show a warning (contents set by warningText)
     */
    warn: boolean;
    /**
     * Sets the warning text
     */
    warnText: string | TemplateRef<any>;
    /**
     * Emits event notifying other classes when a change in state occurs in the input.
     */
    numberChange: EventEmitter<NumberChangeEvent>;
    /**
     * Sets the decrement label text
     */
    decrementLabel: string;
    /**
     * Sets the increment label text
     */
    incrementLabel: string;
    protected _value: number;
    /**
     * Creates an instance of `Number`.
     */
    constructor();
    /**
     * This is the initial value set to the component
     * @param value The input value.
     */
    writeValue(value: any): void;
    /**
     * Sets a method in order to propagate changes back to the form.
     */
    registerOnChange(fn: any): void;
    /**
     * Registers a callback to be triggered when the control has been touched.
     * @param fn Callback to be triggered when the number input is touched.
     */
    registerOnTouched(fn: any): void;
    focusOut(): void;
    /**
     * Sets the disabled state through the model
     */
    setDisabledState(isDisabled: boolean): void;
    /**
     * Called when number input is blurred. Needed to properly implement `ControlValueAccessor`.
     */
    onTouched: () => any;
    /**
     * Method set in `registerOnChange` to propagate changes back to the form.
     */
    propagateChange: (_: any) => void;
    /**
     * Adds `step` to the current `value`.
     */
    onIncrement(): void;
    /**
     * Subtracts `step` to the current `value`.
     */
    onDecrement(): void;
    /**
     * Creates a class of `NumberChange` to emit the change in the `Number`.
     */
    emitChangeEvent(): void;
    onNumberInputChange(event: any): void;
    isTemplate(value: any): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<NumberInputComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NumberInputComponent, "ofe-number-input", never, { "theme": { "alias": "theme"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "skeleton": { "alias": "skeleton"; "required": false; }; "invalid": { "alias": "invalid"; "required": false; }; "id": { "alias": "id"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "size": { "alias": "size"; "required": false; }; "required": { "alias": "required"; "required": false; }; "value": { "alias": "value"; "required": false; }; "min": { "alias": "min"; "required": false; }; "max": { "alias": "max"; "required": false; }; "maxlength": { "alias": "maxlength"; "required": false; }; "minlength": { "alias": "minlength"; "required": false; }; "label": { "alias": "label"; "required": false; }; "helperText": { "alias": "helperText"; "required": false; }; "invalidText": { "alias": "invalidText"; "required": false; }; "step": { "alias": "step"; "required": false; }; "precision": { "alias": "precision"; "required": false; }; "warn": { "alias": "warn"; "required": false; }; "warnText": { "alias": "warnText"; "required": false; }; "decrementLabel": { "alias": "decrementLabel"; "required": false; }; "incrementLabel": { "alias": "incrementLabel"; "required": false; }; }, { "numberChange": "numberChange"; }, never, never, false, never>;
}
